@@ -697,6 +697,9 @@ sub process_test {
       if ($@ =~ /^Undefined subroutine &main::(\w+)/
 	  and $not_yet_defined{$1}) {
 	print "# in='$in'\nok $current_num # Skipped: `$1' is known to be undefined\n";
+      } elsif ($@ =~ /high resolution graphics disabled/
+	       and not Math::Pari::have_graphics()) {
+	print "# in='$in'\nok $current_num # Skipped: graphic is disabled in this build\n";
       } elsif ($@ =~ /gnuplot-like plotting environment not loaded yet/
 	       and $skip_gnuplot) {
 	print "# in='$in'\nok $current_num # Skipped: Term::Gnuplot is not loaded\n";
